@@ -18,7 +18,9 @@ Note:
   FT_library_filename before importing the freetype library and freetype will use
   the specified one.
 '''
+import platform
 import sys
+import os
 from ctypes import *
 from freetype.ft_types import *
 from freetype.ft_enums import *
@@ -33,18 +35,30 @@ if PY3: unicode = str
 
 __dll__    = None
 __handle__ = None
-FT_Library_filename = ctypes.util.find_library('freetype')
-if not FT_Library_filename:
-    try:
-        __dll__ = ctypes.CDLL('libfreetype.so.6')
-    except OSError:
-        __dll__ = None
-if not FT_Library_filename and not __dll__:
+
+# on windows all ctypes does when checking for the library
+# is to append .dll to the end and look for an exact match
+# within any entry in PATH.
+libName = ctypes.util.find_library('freetype')
+
+if libName is None:
+    if platform.system() == 'Windows':
+        # Check current working directory for dll as ctypes fails to do so
+        libName = os.path.join(os.path.realpath('.'), 'freetype.dll')
+    else:
+        libName = 'libfreetype.so.6'
+
+try:
+    dll = ctypes.CDLL(libName)
+    _dllFound = True
+except (OSError, TypeError):
+    _dllFound = False
+
+if not _dllFound:
     raise RuntimeError('Freetype library not found')
-if not __dll__:
-  __dll__ = ctypes.CDLL(FT_Library_filename)
-
 
+__dll__ = dll
+FT_Library_filename = libName
 
 # -----------------------------------------------------------------------------
 # High-level API of FreeType 2
@@ -233,6 +247,15 @@ def set_lcd_filter_weights(a,b,c,d,e):
               'set_lcd_filter_weights require freetype > 2.4.0')
 
 
+def _encode_filename(filename):
+    encoded = filename.encode(sys.getfilesystemencoding())
+    if "?" not in filename and b"?" in encoded:
+        # A bug, decoding mbcs always ignore exception, still isn't fixed in Python 2,
+        # view http://bugs.python.org/issue850997 for detail
+        raise UnicodeError()
+    return encoded
+
+
 
 # -----------------------------------------------------------------------------
 #  Direct wrapper (simple renaming)
@@ -1045,8 +1068,16 @@ class Face( object ):
         face = FT_Face( )
         self._FT_Face = None
         #error = FT_New_Face( library, filename, 0, byref(face) )
-        u_filename = c_char_p(filename.encode())
-        error = FT_New_Face( library, u_filename, index, byref(face) )
+        self._filebodys = []
+        try:
+            u_filename = c_char_p(_encode_filename(filename))
+            error = FT_New_Face( library, u_filename, index, byref(face) )
+        except UnicodeError:
+            with open(filename, mode='rb') as f:
+                filebody = f.read()
+            error = FT_New_Memory_Face( library, filebody, len(filebody),
+                                        index, byref(face) )
+            self._filebodys.append(filebody)  # prevent gc
         if error: raise FT_Exception( error )
         self._filename = filename
         self._index = index
@@ -1080,7 +1111,19 @@ class Face( object ):
         attachments.
         '''
 
-        error = FT_Attach_File( self._FT_Face, filename)
+        try:
+            u_filename = c_char_p(_encode_filename(filename))
+            error = FT_Attach_File( self._FT_Face, u_filename )
+        except UnicodeError:
+            with open(filename, mode='rb') as f:
+                filebody = f.read()
+            parameters = FT_Open_Args()
+            parameters.flags = FT_OPEN_MEMORY
+            parameters.memory_base = filebody
+            parameters.memory_size = len(filebody)
+            parameters.stream = None
+            error = FT_Attach_Stream( self._FT_Face, parameters )
+            self._filebodys.append(filebody)  # prevent gc
         if error: raise FT_Exception( error)
 
 
